@@ -31,10 +31,7 @@ class StorageMessage:
 
     @property
     def updatable_attributes(self) -> tuple[Any, ...]:
-        return (
-            self.context,
-            self.has_plural,
-        )
+        return (self.has_plural,)
 
 
 @dataclass(slots=True)
